<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://ays-pro.com/
 * @since      1.0.0
 *
 * @package    Personal_Dictionary
 * @subpackage Personal_Dictionary/includes
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Personal_Dictionary
 * @subpackage Personal_Dictionary/includes
 * @author     AYS Pro LLC <info@ays-pro.com>
 */
class Personal_Dictionary_Data {

    public static function get_pd_validated_data_from_array($pd){
        global $wpdb;
        // Array for survey validated options
        $settings = array();
        $name_prefix = 'pd_';
        $options = array();
        foreach ($pd as $key => $value) {
            $options[$value['meta_key']] = $value['meta_value'];
        }

        // PD options
        if( isset( $pd->options ) && $pd->options != '' ){
            $options = json_decode( $pd->options, true );
        }


        $settings[ $name_prefix . 'learned_points' ] = (isset($options['learned_points']) && $options['learned_points' ] != '') ? abs( floatval( sanitize_text_field( $options['learned_points' ] ) ) ) : 10;

        $settings[ $name_prefix . 'right_points' ] = (isset($options['right_points' ]) && $options['right_points' ] != '') ? abs( floatval( sanitize_text_field( $options['right_points' ] ) ) ) : 1; 
 
        $settings[ $name_prefix . 'wrong_points' ] = (isset($options['wrong_points' ]) && $options['wrong_points' ] != '') ? abs( floatval( sanitize_text_field( $options['wrong_points' ] ) ) ) : 0.25;
       
        $settings[ $name_prefix . 'enable_full_screen_mode' ] = (isset($options['enable_full_screen_mode' ]) && $options['enable_full_screen_mode' ] == 'on') ? 'on' : 'off';

        $settings[ $name_prefix . 'show_correct_answer' ] = (isset($options['show_correct_answer' ]) && $options['show_correct_answer' ] == 'on') ? true : false;

        // $settings[ $name_prefix . 'word_sorting' ] = (isset($options['word_sorting' ]) && $options['word_sorting' ] != '') ? stripslashes ( sanitize_text_field( $options['word_sorting' ] ) ) : 'word';

        $settings[ $name_prefix . 'bg_color' ] = (isset($options['bg_color' ]) && $options['bg_color' ] != '') ?  sanitize_text_field( $options[ 'bg_color' ] )  : '#ffffff';

        $settings[ $name_prefix . 'main_color' ] = (isset($options['main_color' ]) && $options['main_color' ] != '') ?  sanitize_text_field( $options[ 'main_color' ] )  : '#3f72af';
        
        $settings[ $name_prefix . 'text_color' ] = (isset($options['text_color' ]) && $options['text_color' ] != '') ?  sanitize_text_field( $options[ 'text_color' ] ) : '#000';
        
        $settings[ $name_prefix . 'button_text_color' ] = (isset($options['button_text_color' ]) && $options['button_text_color' ] != '') ?  sanitize_text_field( $options[ 'button_text_color' ] ) : '#ffffff';
        
        $settings[ $name_prefix . 'button_font_size' ] = (isset($options['button_font_size' ]) && $options['button_font_size' ] != '') ?  sanitize_text_field( $options[ 'button_font_size' ] ) : 16;

        $settings[ $name_prefix . 'button_font_size_for_mobile' ] = (isset($options['button_font_size_for_mobile' ]) && $options['button_font_size_for_mobile' ] != '') ?  absint( sanitize_text_field( $options[ 'button_font_size_for_mobile' ] ) ) : 16;
       
        $settings[ $name_prefix . 'buttons_left_right_padding' ] = (isset($options['buttons_left_right_padding' ]) && $options['buttons_left_right_padding' ] != '') ?  sanitize_text_field( $options[ 'buttons_left_right_padding' ] ) : 20;
     
        $settings[ $name_prefix . 'buttons_top_bottom_padding' ] = (isset($options['buttons_top_bottom_padding' ]) && $options['buttons_top_bottom_padding' ] != '') ?  sanitize_text_field( $options[ 'buttons_top_bottom_padding' ] ) : 10;
        
        $settings[ $name_prefix . 'buttons_border_radius' ] = (isset($options['buttons_border_radius' ]) && $options['buttons_border_radius' ] != '') ?  sanitize_text_field( $options[ 'buttons_border_radius' ] ) : 3;
       
        $settings[ $name_prefix . 'question_font_size' ] = (isset($options['question_font_size' ]) && $options['question_font_size' ] != '') ?  absint( sanitize_text_field( $options[ 'question_font_size' ] ) ) : 16;

        $settings[ $name_prefix . 'question_font_size_for_mobile' ] = (isset($options['question_font_size_for_mobile' ]) && $options['question_font_size_for_mobile' ] != '') ?  absint( sanitize_text_field( $options[ 'question_font_size_for_mobile' ] ) ) : 16;

        $settings[ $name_prefix . 'answer_font_size' ] = (isset($options['answer_font_size' ]) && $options['answer_font_size' ] != '') ?  absint( sanitize_text_field( $options[ 'answer_font_size' ] ) ) : 15;

        $settings[ $name_prefix . 'answer_font_size_for_mobile' ] = (isset($options['answer_font_size_for_mobile' ]) && $options['answer_font_size_for_mobile' ] != '') ?  absint( sanitize_text_field( $options[ 'answer_font_size_for_mobile' ] ) ) : 15;

        $settings[ $name_prefix . 'custom_class' ] = (isset($options['custom_class' ]) && $options['custom_class' ] != '') ?  $options['custom_class']  : '';

        // Custom CSS
        $settings[ $name_prefix . 'custom_css' ] = (isset($options['custom_css' ]) && $options['custom_css' ] != '') ? stripslashes( htmlspecialchars_decode( $options['custom_css'] ) ) : '';

        // Pd Title
        $settings[ $name_prefix . 'title' ] = (isset($options['title' ]) && $options['title' ] != '') ? stripslashes( htmlspecialchars_decode( $options['title'] ) ) : '';
        
        // Show PD Title
        $settings[$name_prefix .'show_title'] = isset($options['show_title']) && $options['show_title'] == 'on' ? 'on' : 'off';

        //Title text shadow
        $settings[$name_prefix .'enable_title_text_shadow'] = ( isset($options['enable_title_text_shadow']) && $options['enable_title_text_shadow'] != '') ? esc_attr($options['enable_title_text_shadow']) : 'off';
        $settings[$name_prefix .'enable_title_text_shadow'] = (isset($options['enable_title_text_shadow']) && $options['enable_title_text_shadow'] == 'on') ? true : false;

        $settings[$name_prefix .'title_text_shadow_color'] = (isset($options['title_text_shadow_color']) && $options['title_text_shadow_color'] != '') ? esc_attr($options['title_text_shadow_color']) : '#333';

        //Title Text Shadow X offset
        $settings[$name_prefix .'title_text_shadow_x_offset'] = (isset($options['title_text_shadow_x_offset']) && ( $options['title_text_shadow_x_offset'] ) != '' && ( $options['title_text_shadow_x_offset'] ) != 0) ? esc_attr( intval( $options['title_text_shadow_x_offset'] ) ) : 2;

        //Title Text Shadow Y offset
        $settings[$name_prefix .'title_text_shadow_y_offset'] = (isset($options['title_text_shadow_y_offset']) && ( $options['title_text_shadow_y_offset'] ) != '' && ( $options['title_text_shadow_y_offset'] ) != 0) ? esc_attr( intval( $options['title_text_shadow_y_offset'] ) ) : 2;

        //Title Text Shadow Z offset
        $settings[$name_prefix .'title_text_shadow_z_offset'] = (isset($options['title_text_shadow_z_offset']) && ( $options['title_text_shadow_z_offset'] ) != '' && ( $options['title_text_shadow_z_offset'] ) != 0) ? esc_attr( intval( $options['title_text_shadow_z_offset'] ) ) : 2;

        //Title Alignment
        $settings[$name_prefix .'title_alignment'] = (isset($options['title_alignment']) && ( $options['title_alignment'] ) != '' ) ? sanitize_text_field(  $options['title_alignment'] ) : "left";

        //PD Description
        $settings[$name_prefix .'description'] = (isset($options['pd_description' ]) && $options['pd_description' ] != '') ? stripslashes( htmlspecialchars_decode( $options['pd_description'] ) ) : '';

        // Show PD Description
        $settings[$name_prefix .'show_description'] = isset($options['show_description']) && $options['show_description'] == 'on' ? 'on' : 'off';

        // Description font size
        $settings[$name_prefix . 'description_font_size'] = (isset($options['description_font_size']) && $options['description_font_size'] != '') ?  absint( sanitize_text_field( $options['description_font_size'] ) ) : 18;
        $settings[ $name_prefix . 'description_font_size_for_mobile' ] = (isset($options['description_font_size_for_mobile' ]) && $options['description_font_size_for_mobile' ] != '') ?  absint( sanitize_text_field( $options[ 'description_font_size_for_mobile' ] ) ) : 18;
        return $settings;
    }

     public static function get_pd_globsettings(){
        global $wpdb;
        $globsettings_table = $wpdb->prefix . PERSONAL_DICTIONARY_DB_PREFIX . 'globsettings';
        $sql = "SELECT *
                FROM {$globsettings_table}";
        $pd = $wpdb->get_results( $sql ,'ARRAY_A');
        return $pd;
    }

    public static function hex2rgba($color, $opacity = false){

        $default = 'rgb(0,0,0)';

        //Return default if no color provided
        if (empty($color))
            return $default;

        //Sanitize $color if "#" is provided
        if ($color[0] == '#') {
            $color = substr($color, 1);
        }else{
            return $color;
        }

        //Check if color has 6 or 3 characters and get values
        if (strlen($color) == 6) {
            $hex = array($color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5]);
        } elseif (strlen($color) == 3) {
            $hex = array($color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2]);
        } else {
            return $default;
        }

        //Convert hexadec to rgb
        $rgb = array_map('hexdec', $hex);

        //Check if opacity is set(rgba or rgb)
        if ($opacity) {
            if (abs($opacity) > 1)
                $opacity = 1.0;
            $output = 'rgba(' . implode(",", $rgb) . ',' . $opacity . ')';
        } else {
            $output = 'rgb(' . implode(",", $rgb) . ')';
        }

        //Return rgb(a) color string
        return $output;
    }

    public static function ays_autoembed( $content ) {
        global $wp_embed;

        if ( is_null( $content ) ) {
            return $content;
        }

        $content = stripslashes( wpautop( $content ) );
        $content = $wp_embed->autoembed( $content );
        if ( strpos( $content, '[embed]' ) !== false ) {
            $content = $wp_embed->run_shortcode( $content );
        }
        $content = do_shortcode( $content );
        return $content;
    }


    
}
